@@ -112,12 +112,14 @@ EOT;
         $event1->setAttribute('DTSTAMP', array('year' => 2004, 'month' => 11, 'mday' => 20), array('VALUE' => 'DATE'));
         $event1->setAttribute('SUMMARY', 'Escaped Comma in Description Field');
         $event1->setAttribute('DESCRIPTION', 'There is a comma (escaped with a baskslash) in this sentence and some important words after it, see anything here?');
+        $event1->setAttribute('CATEGORIES', null, array(), true, array('Foo'));
 
         $event2->setAttribute('UID', '20041120-8549-innerjoin-org');
         $event2->setAttribute('DTSTART', array('year' => 2005, 'month' => 5, 'mday' => 4), array('VALUE' => 'DATE'));
         $event2->setAttribute('DTSTAMP', array('year' => 2004, 'month' => 11, 'mday' => 20), array('VALUE' => 'DATE'));
         $event2->setAttribute('SUMMARY', 'Dash (rather than Comma) in the Description Field');
         $event2->setAttribute('DESCRIPTION', 'There are important words after this dash - see anything here or have the words gone?');
+        $event2->setAttribute('CATEGORIES', null, array(), true, array('Foo', 'Foo,Bar', 'Bar'));
 
         $ical->addComponent($event1);
         $ical->addComponent($event2);
@@ -175,17 +177,8 @@ EOT;
         $event->setAttribute('DTSTAMP', $date);
         $event->setAttribute('DTSTART', $date);
         $ical->addComponent($event);
-        $this->assertEquals(
-            'BEGIN:VCALENDAR
-VERSION:2.0
-PRODID:-//The Horde Project//Horde iCalendar Library//EN
-BEGIN:VEVENT
-UID:uid
-DTSTAMP:20100101T010000Z
-DTSTART:20100101T010000Z
-END:VEVENT
-END:VCALENDAR
-',
+        $this->assertStringEqualsFile(
+            __DIR__ . '/fixtures/timezone1.ics',
             $ical->exportVCalendar()
         );
 
@@ -196,17 +189,58 @@ END:VCALENDAR
         $date->setTimezone('Europe/Berlin');
         $event->setAttribute('DTSTART', $date, array('TZID' => 'Europe/Berlin'));
         $ical->addComponent($event);
-        $this->assertEquals(
-            'BEGIN:VCALENDAR
-VERSION:2.0
-PRODID:-//The Horde Project//Horde iCalendar Library//EN
-BEGIN:VEVENT
-UID:uid
-DTSTAMP:20100101T010000Z
-DTSTART;TZID=Europe/Berlin:20100101T020000
-END:VEVENT
-END:VCALENDAR
-',
+        $this->assertStringEqualsFile(
+            __DIR__ . '/fixtures/timezone2.ics',
+            $ical->exportVCalendar()
+        );
+
+        $ical = new Horde_Icalendar();
+        $tz = $ical->parsevCalendar(
+            file_get_contents(__DIR__ . '/fixtures/timezone3.ics')
+        );
+        $tz = $ical->getComponent(0);
+        $ical = new Horde_Icalendar();
+        $ical->addComponent($tz);
+        $event = Horde_Icalendar::newComponent('vevent', $ical);
+        $event->setAttribute('UID', 'uid');
+        $event->setAttribute('DTSTAMP', $date);
+        $date->setTimezone('Europe/Berlin');
+        $event->setAttribute('DTSTART', $date, array('TZID' => 'Europe/Berlin'));
+        $ical->addComponent($event);
+        $ical->addComponent($tz);
+        $event = Horde_Icalendar::newComponent('vevent', $ical);
+        $event->setAttribute('UID', 'uid2');
+        $event->setAttribute('DTSTAMP', $date);
+        $date->setTimezone('Europe/Berlin');
+        $start = clone $date;
+        $start->mday++;
+        $event->setAttribute('DTSTART', $start, array('TZID' => 'Europe/Berlin'));
+        $ical->addComponent($event);
+        $this->assertStringEqualsFile(
+            __DIR__ . '/fixtures/timezone4.ics',
+            $ical->exportVCalendar()
+        );
+    }
+
+    public function testDuration0()
+    {
+        $ical = new Horde_Icalendar;
+        $vevent = Horde_Icalendar::newComponent('VEVENT', $ical);
+        $vevent->setAttribute('SUMMARY', 'Testevent');
+        $vevent->setAttribute('UID', 'XXX');
+        $vevent->setAttribute('DTSTART', array('year' => 2015, 'month' => 7, 'mday' => 1), array('VALUE' => 'DATE'));
+        $vevent->setAttribute('DTSTAMP', array('year' => 2015, 'month' => 7, 'mday' => 1), array('VALUE' => 'DATE'));
+        $vevent->setAttribute('DURATION', 0);
+        $ical->addComponent($vevent);
+        $valarm = Horde_Icalendar::newComponent('VALARM', $vevent);
+        $valarm->setAttribute('TRIGGER', 0, array(
+            'VALUE' => 'DURATION',
+            'RELATED' => 'START',
+        ));
+        $valarm->setAttribute('DESCRIPTION', 'Alarm at event-start');
+        $vevent->addComponent($valarm);
+        $this->assertStringEqualsFile(
+            __DIR__ . '/fixtures/duration0.ics',
             $ical->exportVCalendar()
         );
     }
